/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.droids.handle;

import java.io.IOException;
import java.io.Reader;
import java.io.Writer;

/**
 * Wrapper that allows you to pipe a stream from a reader to a writer via a
 * buffer
 * 
 * @version 1.0
 * 
 */
public class WriterHandler {

  private static final int BUFFER_SIZE = 1024;

  /**
   * Pipes everything from the reader to the writer via a buffer
   * 
   * @param reader
   *                the underlying read to read from
   * @param writer
   *                the destination writer
   * @throws IOException
   */
  protected static void pipe(Reader reader, Writer writer) throws IOException {
    char[] buf = new char[BUFFER_SIZE];
    int read = 0;
    while ((read = reader.read(buf)) >= 0) {
      writer.write(buf, 0, read);
    }
    writer.flush();
  }

}
