/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.droids.impl;

import java.util.Collection;
import java.util.Collections;
import java.util.HashSet;
import java.util.LinkedList;

import org.apache.droids.api.Task;

/**
 * Extend the task queue to ignore any tasks we have already seen
 */
public class SimpleTaskQueueWithHistory<T extends Task> extends LinkedList<T>
{

  private final java.util.Set<String> previous;

  /**
   * Simple queue constructor.
   */
  public SimpleTaskQueueWithHistory()
  {
    super();
    previous = Collections.synchronizedSet(new HashSet<String>());
  }

  @Override
  public boolean offer(T e)
  {
      return add(e);
  }

  @Override
  public boolean add(T e)
  {
    if (previous.add(e.getId())) {
      return super.add(e);
    } else {
      return false;
    }
  }

  @Override
  public boolean addAll(Collection<? extends T> c)
  {
    HashSet<String> ids = new HashSet<String>();
    for (T e : c) {
      ids.add(e.getId());
    }
    if (previous.addAll(ids)) {
      return super.addAll(c);
    } else {
      return false;
    }
  }

  public void clearHistory()
  {
    previous.clear();
  }
}
